from flytekit import ImageSpec
from imagespec_fast_builder import FastImageBuilder


image = ImageSpec(
    name="check-flytekit",
    builder="fast-builder",
    commands=["mkdir /hello", "touch /hello/world.txt"],
)

builder = FastImageBuilder()
builder._build_image(image, push=False)



from flytekit import ImageSpec
from imagespec_fast_builder import FastImageBuilder


comet_ml_package = "git+https://github.com/thomasjpfan/flytekit.git@thomasjpfan/cometml_init#subdirectory=plugins/flytekit-comet-ml"

image = ImageSpec(
    name="check-flytekit",
    builder="fast-builder",
    apt_packages=["git"],
    packages=[comet_ml_package, "comet-ml"],
)

builder = FastImageBuilder()
builder._build_image(image, push=False)



from flytekit import ImageSpec
from imagespec_fast_builder import FastImageBuilder

folding_img = ImageSpec(
    name="unionbio-protein",
    python_version="3.11",
    packages=["numpy"],
    # conda_channels=["bioconda", "conda-forge"],
    # conda_packages=["prodigal", "biotite", "biopython", "py3Dmol"],
    # registry="ghcr.io/unionai-oss",
    # platform="linux/amd64",
)

FastImageBuilder()._build_image(folding_img, push=False)
